@@ -128,7 +128,6 @@ def postgres_insert_batch_without_conflict(df_batch, url, database, table):
 
 
 def postgres_upsert(df, url, db, table, conflict_column):
-    print(f'Upserting {table} from {db} on conflict {conflict_column}...')
     if df.shape[0] > 0:
         engine = sqlalchemy.create_engine(url + db)
         con = engine.raw_connection()
@@ -144,12 +143,12 @@ def postgres_upsert(df, url, db, table, conflict_column):
             try:
                 cur.execute(qry, tuple(j))
             except psycopg2.errors.FeatureNotSupported:
-                print(i)
+                raise
             except psycopg2.ProgrammingError:
-                pass
+                raise
+            con.commit()
         con.commit()
         con.close()
-        print('Done!')
     else:
         print('Empty dataframe on upsert!')
 
